@@ -1,22 +1,20 @@
-/* cellrenderericon.c, based on:
+/*
+ * Copyright (C) 2000 Red Hat, Inc., Jonathan Blandford <jrb@redhat.com>
+ * Copyright (C) 2008 - 2016 The Geeqie Team
  *
- * gtkcellrendererpixbuf.c
- * Copyright (C) 2000  Red Hat, Inc.,  Jonathan Blandford <jrb@redhat.com>
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include <stdlib.h>
@@ -42,13 +40,23 @@ static void gqv_cell_renderer_icon_set_property(GObject		*object,
 static void gqv_cell_renderer_icon_init(GQvCellRendererIcon *celltext);
 static void gqv_cell_renderer_icon_class_init(GQvCellRendererIconClass *class);
 static void gqv_cell_renderer_icon_finalize(GObject *object);
-static void gqv_cell_renderer_icon_get_size(GtkCellRenderer	*cell,
-					    GtkWidget		*widget,
-					    const GdkRectangle	*rectangle,
-					    gint		*x_offset,
-					    gint		*y_offset,
-					    gint		*width,
-					    gint		*height);
+#if GTK_CHECK_VERSION(3,0,0)
+static void gqv_cell_renderer_icon_get_size(GtkCellRenderer    *cell,
+					    GtkWidget	       *widget,
+					    const GdkRectangle *rectangle,
+					    gint	       *x_offset,
+					    gint	       *y_offset,
+					    gint	       *width,
+					    gint	       *height);
+#else
+static void gqv_cell_renderer_icon_get_size(GtkCellRenderer    *cell,
+					    GtkWidget	       *widget,
+					    GdkRectangle       *rectangle,
+					    gint	       *x_offset,
+					    gint	       *y_offset,
+					    gint	       *width,
+					    gint	       *height);
+#endif
 #if GTK_CHECK_VERSION(3,0,0)
 static void gqv_cell_renderer_icon_render(GtkCellRenderer *cell,
 					   cairo_t *cr,
@@ -67,13 +75,23 @@ static void gqv_cell_renderer_icon_render(GtkCellRenderer	*cell,
 #endif
 
 
+#if GTK_CHECK_VERSION(3,0,0)
 static gboolean gqv_cell_renderer_icon_activate(GtkCellRenderer      *cell,
-					    GdkEvent             *event,
-					    GtkWidget            *widget,
-					    const gchar          *path,
-					    const GdkRectangle   *background_area,
-					    const GdkRectangle   *cell_area,
-					    GtkCellRendererState  flags);
+						GdkEvent             *event,
+						GtkWidget            *widget,
+						const gchar          *path,
+						const GdkRectangle   *background_area,
+						const GdkRectangle   *cell_area,
+						GtkCellRendererState  flags);
+#else
+static gboolean gqv_cell_renderer_icon_activate(GtkCellRenderer      *cell,
+						GdkEvent             *event,
+						GtkWidget            *widget,
+						const gchar          *path,
+						GdkRectangle         *background_area,
+						GdkRectangle         *cell_area,
+						GtkCellRendererState  flags);
+#endif
 
 enum {
   TOGGLED,
@@ -550,14 +568,23 @@ gqv_cell_renderer_icon_new(void)
 	return g_object_new(GQV_TYPE_CELL_RENDERER_ICON, NULL);
 }
 
-static void
-gqv_cell_renderer_icon_get_size(GtkCellRenderer *cell,
-				GtkWidget	*widget,
-				const GdkRectangle	*cell_area,
-				gint		*x_offset,
-				gint		*y_offset,
-				gint		*width,
-				gint		*height)
+#if GTK_CHECK_VERSION(3,0,0)
+static void gqv_cell_renderer_icon_get_size(GtkCellRenderer    *cell,
+					    GtkWidget          *widget,
+					    const GdkRectangle *cell_area,
+					    gint	       *x_offset,
+					    gint	       *y_offset,
+					    gint	       *width,
+					    gint	       *height)
+#else
+static void gqv_cell_renderer_icon_get_size(GtkCellRenderer    *cell,
+					    GtkWidget	       *widget,
+					    GdkRectangle       *cell_area,
+					    gint	       *x_offset,
+					    gint	       *y_offset,
+					    gint	       *width,
+					    gint	       *height)
+#endif
 {
 	GQvCellRendererIcon *cellicon = (GQvCellRendererIcon *) cell;
 	gint calc_width;
@@ -845,14 +872,23 @@ gqv_cell_renderer_icon_render(GtkCellRenderer		*cell,
 #endif
 }
 
-static gboolean
-gqv_cell_renderer_icon_activate(GtkCellRenderer      *cell,
-			 	GdkEvent             *event,
-				GtkWidget            *widget,
-				const gchar          *path,
-				const GdkRectangle   *background_area,
-				const GdkRectangle   *cell_area,
-				GtkCellRendererState  flags)
+#if GTK_CHECK_VERSION(3,0,0)
+static gboolean gqv_cell_renderer_icon_activate(GtkCellRenderer      *cell,
+						GdkEvent             *event,
+						GtkWidget            *widget,
+						const gchar          *path,
+						const GdkRectangle   *background_area,
+						const GdkRectangle   *cell_area,
+						GtkCellRendererState  flags)
+#else
+static gboolean gqv_cell_renderer_icon_activate(GtkCellRenderer      *cell,
+						GdkEvent             *event,
+						GtkWidget            *widget,
+						const gchar          *path,
+						GdkRectangle	     *background_area,
+						GdkRectangle	     *cell_area,
+						GtkCellRendererState  flags)
+#endif
 {
 	GQvCellRendererIcon *cellicon = (GQvCellRendererIcon *) cell;
 	GdkEventButton *bevent = &event->button;
