@@ -1,16 +1,24 @@
 /*
- * Geeqie
- * (C) 2004 John Ellis
- * Copyright (C) 2008 - 2012 The Geeqie Team
+ * Copyright (C) 2004 John Ellis
+ * Copyright (C) 2008 - 2016 The Geeqie Team
  *
  * Author: John Ellis
  *
- * This software is released under the GNU General Public License (GNU GPL).
- * Please read the included file COPYING for more information.
- * This software comes with no warranty of any kind, use at your own risk!
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-
 #include "main.h"
 #include "collect-table.h"
 
@@ -519,6 +527,7 @@ static void tip_show(CollectTable *ct)
 {
 	GtkWidget *label;
 	gint x, y;
+	gint x_win = 0, y_win = 0;
 
 	if (ct->tip_window) return;
 
@@ -537,10 +546,14 @@ static void tip_show(CollectTable *ct)
 	gtk_container_add(GTK_CONTAINER(ct->tip_window), label);
 	gtk_widget_show(label);
 
+#if GTK_CHECK_VERSION(3,0,0)
+	gdk_window_get_origin(gtk_widget_get_window(ct->listview), &x_win, &y_win);
+#else
 	gdk_window_get_pointer(NULL, &x, &y, NULL);
+#endif
 
 	if (!gtk_widget_get_realized(ct->tip_window)) gtk_widget_realize(ct->tip_window);
-	gtk_window_move(GTK_WINDOW(ct->tip_window), x + 16, y + 16);
+	gtk_window_move(GTK_WINDOW(ct->tip_window), x_win + x + 16, y_win + y + 16);
 	gtk_widget_show(ct->tip_window);
 }
 
