@@ -1,16 +1,24 @@
 /*
- * Geeqie
- * (C) 2005 John Ellis
- * Copyright (C) 2008 - 2012 The Geeqie Team
+ * Copyright (C) 2005 John Ellis
+ * Copyright (C) 2008 - 2016 The Geeqie Team
  *
  * Author: John Ellis
  *
- * This software is released under the GNU General Public License (GNU GPL).
- * Please read the included file COPYING for more information.
- * This software comes with no warranty of any kind, use at your own risk!
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-
 #include "main.h"
 #include "dupe.h"
 
@@ -404,10 +412,6 @@ static void dupe_item_read_cache(DupeItem *di)
 			di->width = cd->width;
 			di->height = cd->height;
 			}
-		if (di->checksum == 0 && cd->have_checksum)
-			{
-			di->checksum = cd->checksum;
-			}
 		if (!di->md5sum && cd->have_md5sum)
 			{
 			di->md5sum = md5_digest_to_text(cd->md5sum);
@@ -432,7 +436,6 @@ static void dupe_item_write_cache(DupeItem *di)
 		cd->path = cache_get_location(CACHE_TYPE_SIM, di->fd->path, TRUE, NULL);
 
 		if (di->width != 0) cache_sim_data_set_dimensions(cd, di->width, di->height);
-		if (di->checksum != 0) cache_sim_data_set_checksum(cd, di->checksum);
 		if (di->md5sum)
 			{
 			guchar digest[16];
