@@ -1,16 +1,24 @@
 /*
- * Geeqie
- * (C) 2004 John Ellis
- * Copyright (C) 2008 - 2010 The Geeqie Team
+ * Copyright (C) 2004 John Ellis
+ * Copyright (C) 2008 - 2016 The Geeqie Team
  *
  * Author: John Ellis
  *
- * This software is released under the GNU General Public License (GNU GPL).
- * Please read the included file COPYING for more information.
- * This software comes with no warranty of any kind, use at your own risk!
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-
 #ifndef DUPE_H
 #define DUPE_H
 
@@ -24,7 +32,7 @@ typedef enum
 	DUPE_MATCH_SIZE = 1 << 1,
 	DUPE_MATCH_DATE = 1 << 2,
 	DUPE_MATCH_DIM  = 1 << 3,	/* image dimensions */
-	DUPE_MATCH_SUM  = 1 << 4,	/* simple checksum */
+	DUPE_MATCH_SUM  = 1 << 4,	/* MD5sum */
 	DUPE_MATCH_PATH = 1 << 5,
 	DUPE_MATCH_SIM_HIGH = 1 << 6,	/* similarity */
 	DUPE_MATCH_SIM_MED  = 1 << 7,
@@ -41,7 +49,6 @@ struct _DupeItem
 
 	FileData *fd;
 
-	glong checksum;
 	gchar *md5sum;
 	gint width;
 	gint height;
