@@ -1,16 +1,24 @@
 /*
- * Geeqie
- * (C) 2006 John Ellis
- * Copyright (C) 2008 - 2012 The Geeqie Team
+ * Copyright (C) 2006 John Ellis
+ * Copyright (C) 2008 - 2016 The Geeqie Team
  *
  * Author: John Ellis
  *
- * This software is released under the GNU General Public License (GNU GPL).
- * Please read the included file COPYING for more information.
- * This software comes with no warranty of any kind, use at your own risk!
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-
 #include "main.h"
 #include "filedata.h"
 
@@ -165,6 +173,7 @@ static gboolean file_data_check_changed_single_file(FileData *fd, struct stat *s
 		{
 		fd->size = st->st_size;
 		fd->date = st->st_mtime;
+		fd->cdate = st->st_ctime;
 		fd->mode = st->st_mode;
 		if (fd->thumb_pixbuf) g_object_unref(fd->thumb_pixbuf);
 		fd->thumb_pixbuf = NULL;
@@ -394,6 +403,7 @@ static FileData *file_data_new(const gchar *path_utf8, struct stat *st, gboolean
 
 	fd->size = st->st_size;
 	fd->date = st->st_mtime;
+	fd->cdate = st->st_ctime;
 	fd->mode = st->st_mode;
 	fd->ref = 1;
 	fd->magick = FD_MAGICK;
@@ -414,6 +424,27 @@ static FileData *file_data_new_local(const gchar *path, struct stat *st, gboolea
 	return ret;
 }
 
+FileData *file_data_new_simple(const gchar *path_utf8)
+{
+	struct stat st;
+	FileData *fd;
+
+	if (!stat_utf8(path_utf8, &st))
+		{
+		st.st_size = 0;
+		st.st_mtime = 0;
+		}
+
+	fd = g_hash_table_lookup(file_data_pool, path_utf8);
+	if (!fd) fd = file_data_new(path_utf8, &st, TRUE);
+	if (fd)
+		{
+		file_data_ref(fd);
+		}
+
+	return fd;
+}
+
 void init_exif_time_data(GList *files)
 {
 	FileData *file;
@@ -976,6 +1007,11 @@ gint filelist_sort_compare_filedata(FileData *fa, FileData *fb)
 			if (fa->date > fb->date) return 1;
 			/* fall back to name */
 			break;
+		case SORT_CTIME:
+			if (fa->cdate < fb->cdate) return -1;
+			if (fa->cdate > fb->cdate) return 1;
+			/* fall back to name */
+			break;
 		case SORT_EXIFTIME:
 			if (fa->exifdate < fb->exifdate) return -1;
 			if (fa->exifdate > fb->exifdate) return 1;
@@ -2156,10 +2192,12 @@ gboolean file_data_sc_update_ci_unspecified_list(GList *fd_list, const gchar *de
  * it should detect all possible problems with the planned operation
  */
 
-gint file_data_verify_ci(FileData *fd)
+gint file_data_verify_ci(FileData *fd, GList *list)
 {
 	gint ret = CHANGE_OK;
 	gchar *dir;
+	GList *work = NULL;
+	FileData *fd1 = NULL;
 
 	if (!fd->change)
 		{
@@ -2316,11 +2354,13 @@ gint file_data_verify_ci(FileData *fd)
 			{
 			const gchar *dest_ext = extension_from_path(fd->change->dest);
 			if (!dest_ext) dest_ext = "";
-
-			if (g_ascii_strcasecmp(fd->extension, dest_ext) != 0)
+			if (!options->file_filter.disable_file_extension_checks)
 				{
-				ret |= CHANGE_WARN_CHANGED_EXT;
-				DEBUG_1("Change checked: source and destination have different extensions: %s -> %s", fd->path, fd->change->dest);
+				if (g_ascii_strcasecmp(fd->extension, dest_ext) != 0)
+					{
+					ret |= CHANGE_WARN_CHANGED_EXT;
+					DEBUG_1("Change checked: source and destination have different extensions: %s -> %s", fd->path, fd->change->dest);
+					}
 				}
 			}
 		else
@@ -2369,6 +2409,26 @@ gint file_data_verify_ci(FileData *fd)
 		g_free(dest_dir);
 		}
 
+	/* During a rename operation, check if another planned destination file has
+	 * the same filename
+	 */
+ 	if(fd->change->type == FILEDATA_CHANGE_RENAME)
+		{
+		work = list;
+		while (work)
+			{
+			fd1 = work->data;
+			work = work->next;
+			if (fd1 != NULL && fd != fd1 )
+				{
+				if (!strcmp(fd->change->dest, fd1->change->dest))
+					{
+					ret |= CHANGE_DUPLICATE_DEST;
+					}
+				}
+			}
+		}
+
 	fd->change->error = ret;
 	if (ret == 0) DEBUG_1("Change checked: OK: %s", fd->path);
 
@@ -2377,19 +2437,19 @@ gint file_data_verify_ci(FileData *fd)
 }
 
 
-gint file_data_sc_verify_ci(FileData *fd)
+gint file_data_sc_verify_ci(FileData *fd, GList *list)
 {
 	GList *work;
 	gint ret;
 
-	ret = file_data_verify_ci(fd);
+	ret = file_data_verify_ci(fd, list);
 
 	work = fd->sidecar_files;
 	while (work)
 		{
 		FileData *sfd = work->data;
 
-		ret |= file_data_verify_ci(sfd);
+		ret |= file_data_verify_ci(sfd, list);
 		work = work->next;
 		}
 
@@ -2472,6 +2532,12 @@ gchar *file_data_get_error_string(gint error)
 		g_string_append(result, _("there are unsaved metadata changes for the file"));
 		}
 
+	if (error & CHANGE_DUPLICATE_DEST)
+		{
+		if (result->len > 0) g_string_append(result, ", ");
+		g_string_append(result, _("another destination file has the same filename"));
+		}
+
 	return g_string_free(result, FALSE);
 }
 
@@ -2498,7 +2564,7 @@ gint file_data_verify_ci_list(GList *list, gchar **desc, gboolean with_sidecars)
 		fd = work->data;
 		work = work->next;
 
-		error = with_sidecars ? file_data_sc_verify_ci(fd) : file_data_verify_ci(fd);
+		error = with_sidecars ? file_data_sc_verify_ci(fd, list) : file_data_verify_ci(fd, list);
 		all_errors |= error;
 		common_errors &= error;
 
@@ -2851,10 +2917,21 @@ gboolean file_data_send_notification_idle_cb(gpointer data)
 
 void file_data_send_notification(FileData *fd, NotifyType type)
 {
+	GList *work = notify_func_list;
+
+	while (work)
+		{
+		NotifyData *nd = (NotifyData *)work->data;
+
+		nd->func(fd, type, nd->data);
+		work = work->next;
+		}
+    /*
 	NotifyIdleData *nid = g_new0(NotifyIdleData, 1);
 	nid->fd = file_data_ref(fd);
 	nid->type = type;
 	g_idle_add_full(G_PRIORITY_HIGH, file_data_send_notification_idle_cb, nid, NULL);
+    */
 }
 
 static GHashTable *file_data_monitor_pool = NULL;
