@@ -1,16 +1,24 @@
 /*
- * Geeqie
- * (C) 2004 John Ellis
- * Copyright (C) 2008 - 2012 The Geeqie Team
+ * Copyright (C) 2004 John Ellis
+ * Copyright (C) 2008 - 2016 The Geeqie Team
  *
  * Author: John Ellis
  *
- * This software is released under the GNU General Public License (GNU GPL).
- * Please read the included file COPYING for more information.
- * This software comes with no warranty of any kind, use at your own risk!
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-
 #include "main.h"
 #include "layout_util.h"
 
@@ -45,7 +53,6 @@
 #include "view_dir.h"
 #include "window.h"
 #include "metadata.h"
-#include "rcfile.h"
 #include "desktop_file.h"
 
 #include <gdk/gdkkeysyms.h> /* for keyboard values */
@@ -1066,6 +1073,25 @@ static void layout_menu_home_cb(GtkAction *action, gpointer data)
 		}
 }
 
+static void layout_menu_up_cb(GtkAction *action, gpointer data)
+{
+	LayoutWindow *lw = data;
+	ViewDir *vd = lw->vd;
+	gchar *path;
+
+	if (!vd->dir_fd || strcmp(vd->dir_fd->path, G_DIR_SEPARATOR_S) == 0) return;
+	path = remove_level_from_path(vd->dir_fd->path);
+
+	if (vd->select_func)
+		{
+		FileData *fd = file_data_new_dir(path);
+		vd->select_func(vd, fd, vd->select_data);
+		file_data_unref(fd);
+		}
+
+	g_free(path);
+}
+
 
 /*
  *-----------------------------------------------------------------------------
@@ -1248,33 +1274,34 @@ void layout_recent_add_path(const gchar *path)
 #define CB G_CALLBACK
 
 static GtkActionEntry menu_entries[] = {
-  { "FileMenu",		NULL,			N_("_File"),				NULL, 			NULL,					NULL },
-  { "GoMenu",		NULL,			N_("_Go"),				NULL, 			NULL,					NULL },
-  { "EditMenu",		NULL,			N_("_Edit"),				NULL, 			NULL,					NULL },
-  { "SelectMenu",	NULL,			N_("_Select"),				NULL, 			NULL,					NULL },
-  { "OrientationMenu",	NULL,			N_("_Orientation"),			NULL, 			NULL,					NULL },
-  { "ExternalMenu",	NULL,			N_("E_xternal Editors"),		NULL, 			NULL,					NULL },
-  { "PreferencesMenu",	NULL,			N_("P_references"),			NULL, 			NULL,					NULL },
-  { "ViewMenu",		NULL,			N_("_View"),				NULL, 			NULL,					NULL },
-  { "FileDirMenu",	NULL,			N_("_Files and Folders"),		NULL, 			NULL,					NULL },
-  { "ZoomMenu",		NULL,			N_("_Zoom"),				NULL, 			NULL,					NULL },
-  { "ColorMenu",	NULL,			N_("_Color Management"),		NULL, 			NULL,					NULL },
-  { "ConnectZoomMenu",	NULL,			N_("_Connected Zoom"),			NULL, 			NULL,					NULL },
-  { "SplitMenu",	NULL,			N_("Spli_t"),				NULL, 			NULL,					NULL },
-  { "StereoMenu",	NULL,			N_("Stere_o"),				NULL, 			NULL,					NULL },
-  { "OverlayMenu",	NULL,			N_("Image _Overlay"),			NULL, 			NULL,					NULL },
-  { "HelpMenu",		NULL,			N_("_Help"),				NULL, 			NULL,					NULL },
+  { "FileMenu",		NULL,			N_("_File"),				NULL,			NULL,					NULL },
+  { "GoMenu",		NULL,			N_("_Go"),				NULL,			NULL,					NULL },
+  { "EditMenu",		NULL,			N_("_Edit"),				NULL,			NULL,					NULL },
+  { "SelectMenu",	NULL,			N_("_Select"),				NULL,			NULL,					NULL },
+  { "OrientationMenu",	NULL,			N_("_Orientation"),			NULL,			NULL,					NULL },
+  { "ExternalMenu",	NULL,			N_("E_xternal Editors"),		NULL,			NULL,					NULL },
+  { "PreferencesMenu",	NULL,			N_("P_references"),			NULL,			NULL,					NULL },
+  { "ViewMenu",		NULL,			N_("_View"),				NULL,			NULL,					NULL },
+  { "FileDirMenu",	NULL,			N_("_Files and Folders"),		NULL,			NULL,					NULL },
+  { "ZoomMenu",		NULL,			N_("_Zoom"),				NULL,			NULL,					NULL },
+  { "ColorMenu",	NULL,			N_("_Color Management"),		NULL,			NULL,					NULL },
+  { "ConnectZoomMenu",	NULL,			N_("_Connected Zoom"),			NULL,			NULL,					NULL },
+  { "SplitMenu",	NULL,			N_("Spli_t"),				NULL,			NULL,					NULL },
+  { "StereoMenu",	NULL,			N_("Stere_o"),				NULL,			NULL,					NULL },
+  { "OverlayMenu",	NULL,			N_("Image _Overlay"),			NULL,			NULL,					NULL },
+  { "HelpMenu",		NULL,			N_("_Help"),				NULL,			NULL,					NULL },
 
   { "FirstImage",	GTK_STOCK_GOTO_TOP,	N_("_First Image"),			"Home",			N_("First Image"),			CB(layout_menu_image_first_cb) },
-  { "PrevImage",	GTK_STOCK_GO_UP,   	N_("_Previous Image"),			"BackSpace",		N_("Previous Image"),			CB(layout_menu_image_prev_cb) },
-  { "PrevImageAlt1",	GTK_STOCK_GO_UP,   	N_("_Previous Image"),			"Page_Up",		N_("Previous Image"),			CB(layout_menu_image_prev_cb) },
-  { "PrevImageAlt2",	GTK_STOCK_GO_UP,   	N_("_Previous Image"),			"KP_Page_Up",		N_("Previous Image"),			CB(layout_menu_image_prev_cb) },
+  { "PrevImage",	GTK_STOCK_GO_UP,	N_("_Previous Image"),			"BackSpace",		N_("Previous Image"),			CB(layout_menu_image_prev_cb) },
+  { "PrevImageAlt1",	GTK_STOCK_GO_UP,	N_("_Previous Image"),			"Page_Up",		N_("Previous Image"),			CB(layout_menu_image_prev_cb) },
+  { "PrevImageAlt2",	GTK_STOCK_GO_UP,	N_("_Previous Image"),			"KP_Page_Up",		N_("Previous Image"),			CB(layout_menu_image_prev_cb) },
   { "NextImage",	GTK_STOCK_GO_DOWN,	N_("_Next Image"),			"space",		N_("Next Image"),			CB(layout_menu_image_next_cb) },
   { "NextImageAlt1",	GTK_STOCK_GO_DOWN,	N_("_Next Image"),			"Page_Down",		N_("Next Image"),			CB(layout_menu_image_next_cb) },
   { "NextImageAlt2",	GTK_STOCK_GO_DOWN,	N_("_Next Image"),			"KP_Page_Down",		N_("Next Image"),			CB(layout_menu_image_next_cb) },
   { "LastImage",	GTK_STOCK_GOTO_BOTTOM,	N_("_Last Image"),			"End",			N_("Last Image"),			CB(layout_menu_image_last_cb) },
   { "Back",		GTK_STOCK_GO_BACK,	N_("_Back"),				NULL,			N_("Back"),				CB(layout_menu_back_cb) },
   { "Home",		GTK_STOCK_HOME,		N_("_Home"),				NULL,			N_("Home"),				CB(layout_menu_home_cb) },
+  { "Up",		GTK_STOCK_GO_UP,	N_("_Up"),				NULL,			N_("Up"),				CB(layout_menu_up_cb) },
 
   { "NewWindow",	GTK_STOCK_NEW,		N_("New _window"),			"<control>N",		N_("New window"),			CB(layout_menu_new_window_cb) },
   { "NewCollection",	GTK_STOCK_INDEX,	N_("_New collection"),			"C",			N_("New collection"),			CB(layout_menu_new_cb) },
@@ -1466,6 +1493,7 @@ static const gchar *menu_ui_description =
 "      <menuitem action='LastImage'/>"
 "      <separator/>"
 "      <menuitem action='Back'/>"
+"      <menuitem action='Up'/>"
 "      <menuitem action='Home'/>"
 "      <separator/>"
 "    </menu>"
@@ -1629,8 +1657,22 @@ static const gchar *menu_ui_description =
 "    </menu>"
 "  </menubar>"
 "  <toolbar name='ToolBar'>"
+"    <toolitem action='Thumbnails'/>"
+"    <toolitem action='Back'/>"
+"    <toolitem action='Up'/>"
+"    <toolitem action='Home'/>"
+"    <toolitem action='Refresh'/>"
+"    <toolitem action='ZoomIn'/>"
+"    <toolitem action='ZoomOut'/>"
+"    <toolitem action='ZoomFit'/>"
+"    <toolitem action='Zoom100'/>"
+"    <toolitem action='Preferences'/>"
+"    <toolitem action='FloatTools'/>"
 "  </toolbar>"
 "  <toolbar name='StatusBar'>"
+"    <toolitem action='ShowInfoPixel'/>"
+"    <toolitem action='UseColorProfiles'/>"
+"    <toolitem action='SaveMetadata'/>"
 "  </toolbar>"
 "<accelerator action='PrevImageAlt1'/>"
 "<accelerator action='PrevImageAlt2'/>"
@@ -1698,17 +1740,17 @@ static void layout_actions_setup_marks(LayoutWindow *lw)
 
 	for (mark = 1; mark <= FILEDATA_MARKS_SIZE; mark++)
 		{
-		layout_actions_setup_mark(lw, mark, "Mark%d", 		_("Mark _%d"), NULL, NULL, NULL);
-		layout_actions_setup_mark(lw, mark, "SetMark%d", 	_("_Set mark %d"), 			NULL, 		_("Set mark %d"), G_CALLBACK(layout_menu_set_mark_sel_cb));
-		layout_actions_setup_mark(lw, mark, "ResetMark%d", 	_("_Reset mark %d"), 			NULL, 		_("Reset mark %d"), G_CALLBACK(layout_menu_res_mark_sel_cb));
-		layout_actions_setup_mark(lw, mark, "ToggleMark%d", 	_("_Toggle mark %d"), 			"%d",  		_("Toggle mark %d"), G_CALLBACK(layout_menu_toggle_mark_sel_cb));
-		layout_actions_setup_mark(lw, mark, "ToggleMark%dAlt1",	_("_Toggle mark %d"), 			"KP_%d", 	_("Toggle mark %d"), G_CALLBACK(layout_menu_toggle_mark_sel_cb));
-		layout_actions_setup_mark(lw, mark, "SelectMark%d", 	_("Se_lect mark %d"), 			"<control>%d", 	_("Select mark %d"), G_CALLBACK(layout_menu_sel_mark_cb));
-		layout_actions_setup_mark(lw, mark, "SelectMark%dAlt1",	_("_Select mark %d"), 			"<control>KP_%d", _("Select mark %d"), G_CALLBACK(layout_menu_sel_mark_cb));
-		layout_actions_setup_mark(lw, mark, "AddMark%d", 	_("_Add mark %d"), 			NULL, 		_("Add mark %d"), G_CALLBACK(layout_menu_sel_mark_or_cb));
-		layout_actions_setup_mark(lw, mark, "IntMark%d", 	_("_Intersection with mark %d"), 	NULL, 		_("Intersection with mark %d"), G_CALLBACK(layout_menu_sel_mark_and_cb));
-		layout_actions_setup_mark(lw, mark, "UnselMark%d", 	_("_Unselect mark %d"), 		NULL, 		_("Unselect mark %d"), G_CALLBACK(layout_menu_sel_mark_minus_cb));
-		layout_actions_setup_mark(lw, mark, "FilterMark%d", 	_("_Filter mark %d"), 			NULL, 		_("Filter mark %d"), G_CALLBACK(layout_menu_mark_filter_toggle_cb));
+		layout_actions_setup_mark(lw, mark, "Mark%d",		_("Mark _%d"), NULL, NULL, NULL);
+		layout_actions_setup_mark(lw, mark, "SetMark%d",	_("_Set mark %d"),			NULL,		_("Set mark %d"), G_CALLBACK(layout_menu_set_mark_sel_cb));
+		layout_actions_setup_mark(lw, mark, "ResetMark%d",	_("_Reset mark %d"),			NULL,		_("Reset mark %d"), G_CALLBACK(layout_menu_res_mark_sel_cb));
+		layout_actions_setup_mark(lw, mark, "ToggleMark%d",	_("_Toggle mark %d"),			"%d",		_("Toggle mark %d"), G_CALLBACK(layout_menu_toggle_mark_sel_cb));
+		layout_actions_setup_mark(lw, mark, "ToggleMark%dAlt1",	_("_Toggle mark %d"),			"KP_%d",	_("Toggle mark %d"), G_CALLBACK(layout_menu_toggle_mark_sel_cb));
+		layout_actions_setup_mark(lw, mark, "SelectMark%d",	_("Se_lect mark %d"),			"<control>%d",	_("Select mark %d"), G_CALLBACK(layout_menu_sel_mark_cb));
+		layout_actions_setup_mark(lw, mark, "SelectMark%dAlt1",	_("_Select mark %d"),			"<control>KP_%d", _("Select mark %d"), G_CALLBACK(layout_menu_sel_mark_cb));
+		layout_actions_setup_mark(lw, mark, "AddMark%d",	_("_Add mark %d"),			NULL,		_("Add mark %d"), G_CALLBACK(layout_menu_sel_mark_or_cb));
+		layout_actions_setup_mark(lw, mark, "IntMark%d",	_("_Intersection with mark %d"),	NULL,		_("Intersection with mark %d"), G_CALLBACK(layout_menu_sel_mark_and_cb));
+		layout_actions_setup_mark(lw, mark, "UnselMark%d",	_("_Unselect mark %d"),			NULL,		_("Unselect mark %d"), G_CALLBACK(layout_menu_sel_mark_minus_cb));
+		layout_actions_setup_mark(lw, mark, "FilterMark%d",	_("_Filter mark %d"),			NULL,		_("Filter mark %d"), G_CALLBACK(layout_menu_mark_filter_toggle_cb));
 
 		g_string_append_printf(desc,
 				"      <menu action='Mark%d'>"
@@ -1955,14 +1997,6 @@ void layout_actions_setup(LayoutWindow *lw)
 		exit(EXIT_FAILURE);
 		}
 
-	DEBUG_1("%s layout_actions_setup: add toolbar", get_exec_time());
-	for (i = 0; i < TOOLBAR_COUNT; i++)
-		{
-		layout_toolbar_clear(lw, i);
-		layout_toolbar_add_default(lw, i);
-		}
-
-
 	DEBUG_1("%s layout_actions_setup: marks", get_exec_time());
 	layout_actions_setup_marks(lw);
 
@@ -2084,143 +2118,6 @@ GtkWidget *layout_actions_toolbar(LayoutWindow *lw, ToolbarType type)
 	return lw->toolbar[type];
 }
 
-void layout_toolbar_clear(LayoutWindow *lw, ToolbarType type)
-{
-	if (lw->toolbar_merge_id[type])
-		{
-		gtk_ui_manager_remove_ui(lw->ui_manager, lw->toolbar_merge_id[type]);
-		gtk_ui_manager_ensure_update(lw->ui_manager);
-		}
-	string_list_free(lw->toolbar_actions[type]);
-	lw->toolbar_actions[type] = NULL;
-
-	lw->toolbar_merge_id[type] = gtk_ui_manager_new_merge_id(lw->ui_manager);
-}
-
-
-void layout_toolbar_add(LayoutWindow *lw, ToolbarType type, const gchar *action)
-{
-	const gchar *path = NULL;
-	if (!action || !lw->ui_manager) return;
-
-	if (g_list_find_custom(lw->toolbar_actions[type], action, (GCompareFunc)strcmp)) return;
-
-	switch (type)
-		{
-		case TOOLBAR_MAIN:
-			path = "/ToolBar";
-			break;
-		case TOOLBAR_STATUS:
-			path = "/StatusBar";
-			break;
-		default:
-			break;
-		}
-
-
-	if (g_str_has_suffix(action, ".desktop"))
-		{
-		/* this may be called before the external editors are read
-		   create a dummy action for now */
-
-		if (!lw->action_group_editors)
-			{
-			lw->action_group_editors = gtk_action_group_new("MenuActionsExternal");
-			gtk_ui_manager_insert_action_group(lw->ui_manager, lw->action_group_editors, 1);
-			}
-		if (!gtk_action_group_get_action(lw->action_group_editors, action))
-			{
-			GtkActionEntry entry = { action,
-			                         GTK_STOCK_MISSING_IMAGE,
-			                         action,
-			                         NULL,
-			                         NULL,
-			                         NULL };
-			DEBUG_1("Creating temporary action %s", action);
-			gtk_action_group_add_actions(lw->action_group_editors, &entry, 1, lw);
-			}
-		}
-	gtk_ui_manager_add_ui(lw->ui_manager, lw->toolbar_merge_id[type], path, action, action, GTK_UI_MANAGER_TOOLITEM, FALSE);
-	lw->toolbar_actions[type] = g_list_append(lw->toolbar_actions[type], g_strdup(action));
-}
-
-
-void layout_toolbar_add_default(LayoutWindow *lw, ToolbarType type)
-{
-	switch (type)
-		{
-		case TOOLBAR_MAIN:
-			layout_toolbar_add(lw, type, "Thumbnails");
-			layout_toolbar_add(lw, type, "Back");
-			layout_toolbar_add(lw, type, "Home");
-			layout_toolbar_add(lw, type, "Refresh");
-			layout_toolbar_add(lw, type, "ZoomIn");
-			layout_toolbar_add(lw, type, "ZoomOut");
-			layout_toolbar_add(lw, type, "ZoomFit");
-			layout_toolbar_add(lw, type, "Zoom100");
-			layout_toolbar_add(lw, type, "Preferences");
-			layout_toolbar_add(lw, type, "FloatTools");
-			break;
-		case TOOLBAR_STATUS:
-			layout_toolbar_add(lw, type, "ShowInfoPixel");
-			layout_toolbar_add(lw, type, "UseColorProfiles");
-			layout_toolbar_add(lw, type, "SaveMetadata");
-			break;
-		default:
-			break;
-		}
-}
-
-void layout_toolbar_write_config(LayoutWindow *lw, ToolbarType type, GString *outstr, gint indent)
-{
-	const gchar *name = NULL;
-	GList *work = lw->toolbar_actions[type];
-
-	switch (type)
-		{
-		case TOOLBAR_MAIN:
-			name = "toolbar";
-			break;
-		case TOOLBAR_STATUS:
-			name = "statusbar";
-			break;
-		default:
-			break;
-		}
-
-	WRITE_NL(); WRITE_STRING("<%s>", name);
-	indent++;
-	WRITE_NL(); WRITE_STRING("<clear/>");
-	while (work)
-		{
-		gchar *action = work->data;
-		work = work->next;
-		WRITE_NL(); WRITE_STRING("<toolitem ");
-		write_char_option(outstr, indent + 1, "action", action);
-		WRITE_STRING("/>");
-		}
-	indent--;
-	WRITE_NL(); WRITE_STRING("</%s>", name);
-}
-
-void layout_toolbar_add_from_config(LayoutWindow *lw, ToolbarType type, const gchar **attribute_names, const gchar **attribute_values)
-{
-	gchar *action = NULL;
-
-	while (*attribute_names)
-		{
-		const gchar *option = *attribute_names++;
-		const gchar *value = *attribute_values++;
-
-		if (READ_CHAR_FULL("action", action)) continue;
-
-		log_printf("unknown attribute %s = %s\n", option, value);
-		}
-
-	layout_toolbar_add(lw, type, action);
-	g_free(action);
-}
-
 /*
  *-----------------------------------------------------------------------------
  * misc
