@@ -1,13 +1,22 @@
 /*
- * Geeqie
- * (C) 2006 John Ellis
- * Copyright (C) 2008 - 2012 The Geeqie Team
+ * Copyright (C) 2006 John Ellis
+ * Copyright (C) 2008 - 2016 The Geeqie Team
  *
  * Author: John Ellis
  *
- * This software is released under the GNU General Public License (GNU GPL).
- * Please read the included file COPYING for more information.
- * This software comes with no warranty of any kind, use at your own risk!
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include <gdk/gdkkeysyms.h> /* for keyboard values */
@@ -320,19 +329,20 @@ static void parse_command_line(gint argc, gchar *argv[])
 				printf_term("%s %s\n", GQ_APPNAME, VERSION);
 				printf_term(_("Usage: %s [options] [path]\n\n"), GQ_APPNAME_LC);
 				print_term(_("valid options are:\n"));
-				print_term(_("  +t, --with-tools           force show of tools\n"));
-				print_term(_("  -t, --without-tools        force hide of tools\n"));
-				print_term(_("  -f, --fullscreen           start in full screen mode\n"));
-				print_term(_("  -s, --slideshow            start in slideshow mode\n"));
-				print_term(_("  -l, --list                 open collection window for command line\n"));
-				print_term(_("      --geometry=GEOMETRY    set main window location\n"));
-				print_term(_("  -r, --remote               send following commands to open window\n"));
-				print_term(_("  -rh,--remote-help          print remote command list\n"));
+				print_term(_("  +t, --with-tools                 force show of tools\n"));
+				print_term(_("  -t, --without-tools              force hide of tools\n"));
+				print_term(_("  -f, --fullscreen                 start in full screen mode\n"));
+				print_term(_("  -s, --slideshow                  start in slideshow mode\n"));
+				print_term(_("  -l, --list [files] [collections] open collection window for command line\n"));
+				print_term(_("      --blank                      start with blank file list\n"));
+				print_term(_("      --geometry=XxY+XOFF+YOFF     set main window location\n"));
+				print_term(_("  -r, --remote                     send following commands to open window\n"));
+				print_term(_("  -rh,--remote-help                print remote command list\n"));
 #ifdef DEBUG
-				print_term(_("  --debug[=level]            turn on debug output\n"));
+				print_term(_("      --debug[=level]              turn on debug output\n"));
 #endif
-				print_term(_("  -v, --version              print version info\n"));
-				print_term(_("  -h, --help                 show this message\n\n"));
+				print_term(_("  -v, --version                    print version info\n"));
+				print_term(_("  -h, --help                       show this message\n\n"));
 
 #if 0
 				/* these options are not officially supported!
@@ -340,6 +350,7 @@ static void parse_command_line(gint argc, gchar *argv[])
 				print_term(  "  --alternate                use alternate similarity algorithm\n");
 #endif
 
+
 				exit(0);
 				}
 			else if (!remote_do)
@@ -737,7 +748,9 @@ gint main(gint argc, gchar *argv[])
 	CollectionData *cd = NULL;
 
 #ifdef HAVE_GTHREAD
+#if !GLIB_CHECK_VERSION(2,32,0)
 	g_thread_init(NULL);
+#endif
 	gdk_threads_init();
 	gdk_threads_enter();
 
