@@ -1,13 +1,21 @@
 /*
- * Geeqie
- * Copyright (C) 2008 - 2012 The Geeqie Team
+ * Copyright (C) 2008, 2016 The Geeqie Team -
  *
  * Authors: Vladimir Nadvornik, Laurent Monin
  *
- * This software is released under the GNU General Public License (GNU GPL).
- * Please read the included file COPYING for more information.
- * This software comes with no warranty of any kind, use at your own risk!
- */
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA. */
 
 #include "main.h"
 #include "options.h"
@@ -38,10 +46,13 @@ ConfOptions *init_options(ConfOptions *options)
 
 	options->dnd_icon_size = 48;
 	options->duplicates_similarity_threshold = 99;
-	
+	options->rot_invariant_sim = TRUE;
+
 	options->file_filter.disable = FALSE;
 	options->file_filter.show_dot_directory = FALSE;
 	options->file_filter.show_hidden_files = FALSE;
+	options->file_filter.show_parent_directory = TRUE;
+	options->file_filter.disable_file_extension_checks = FALSE;
 
 	options->save_window_positions = TRUE;
 	options->tools_restore_state = TRUE;
@@ -63,9 +74,9 @@ ConfOptions *init_options(ConfOptions *options)
 	options->fullscreen.screen = -1;
 
 	memset(&options->image.border_color, 0, sizeof(options->image.border_color));
-	options->image.dither_quality = GDK_RGB_DITHER_NORMAL;
 	options->image.enable_read_ahead = TRUE;
 	options->image.exif_rotate_enable = TRUE;
+	options->image.exif_proof_rotate_enable = TRUE;
 	options->image.fit_window_to_image = FALSE;
 	options->image.limit_autofit_size = FALSE;
 	options->image.limit_window_size = TRUE;
@@ -85,6 +96,15 @@ ConfOptions *init_options(ConfOptions *options)
 	options->image_overlay.template_string = NULL;
 	options->image_overlay.x = 10;
 	options->image_overlay.y = -10;
+	options->image_overlay.font = NULL;
+	options->image_overlay.text_red = 0;
+	options->image_overlay.text_green = 0;
+	options->image_overlay.text_blue = 0;
+	options->image_overlay.text_alpha = 255;
+	options->image_overlay.background_red = 240;
+	options->image_overlay.background_green = 240;
+	options->image_overlay.background_blue = 240;
+	options->image_overlay.background_alpha = 210;
 
 	options->lazy_image_sync = FALSE;
 	options->mousewheel_scrolls = FALSE;
@@ -92,7 +112,7 @@ ConfOptions *init_options(ConfOptions *options)
 	options->place_dialogs_under_mouse = FALSE;
 
 	options->progressive_key_scrolling = TRUE;
-	
+
 	options->metadata.enable_metadata_dirs = FALSE;
 	options->metadata.save_in_image_file = FALSE;
 	options->metadata.save_legacy_IPTC = FALSE;
@@ -106,7 +126,7 @@ ConfOptions *init_options(ConfOptions *options)
 	options->metadata.confirm_on_dir_change = TRUE;
 	options->metadata.keywords_case_sensitive = FALSE;
 	options->metadata.write_orientation = TRUE;
-	
+
 	options->show_icon_names = TRUE;
 
 	options->slideshow.delay = 50;
@@ -124,7 +144,7 @@ ConfOptions *init_options(ConfOptions *options)
 
 	options->tree_descend_subdirs = FALSE;
 	options->update_on_time_change = TRUE;
-	
+
 	options->stereo.fixed_w = 1920;
 	options->stereo.fixed_h = 1080;
 	options->stereo.fixed_x1 = 0;
@@ -140,6 +160,7 @@ void setup_default_options(ConfOptions *options)
 	gchar *path;
 	gint i;
 
+	bookmark_add_default(".", get_current_dir());
 	bookmark_add_default(_("Home"), homedir());
 	path = g_build_filename(homedir(), "Desktop", NULL);
 	bookmark_add_default(_("Desktop"), path);
@@ -160,17 +181,12 @@ void setup_default_options(ConfOptions *options)
 
 	options->shell.path = g_strdup(GQ_DEFAULT_SHELL_PATH);
 	options->shell.options = g_strdup(GQ_DEFAULT_SHELL_OPTIONS);
-
-#if 0	
-	for (i = 0; ExifUIList[i].key; i++)
-		ExifUIList[i].current = ExifUIList[i].default_value;
-#endif
 }
 
 void copy_layout_options(LayoutOptions *dest, const LayoutOptions *src)
 {
 	free_layout_options_content(dest);
-	
+
 	*dest = *src;
 	dest->id = g_strdup(src->id);
 	dest->order = g_strdup(src->order);
@@ -260,7 +276,7 @@ gboolean load_options(ConfOptions *options)
 		DEBUG_1("Loading options from %s ... %s", rc_path, success ? "done" : "failed");
 		g_free(rc_path);
 		}
-	
+
 	rc_path = g_build_filename(get_rc_dir(), RC_FILE_NAME, NULL);
 	success = load_config_from_file(rc_path, TRUE);
 	DEBUG_1("Loading options from %s ... %s", rc_path, success ? "done" : "failed");
