@@ -1,12 +1,21 @@
 /*
- * Geeqie
- * Copyright (C) 2008 - 2012 The Geeqie Team
+ * Copyright (C) 2008 - 2016 The Geeqie Team
  *
  * Authors: Vladimir Nadvornik, Laurent Monin
  *
- * This software is released under the GNU General Public License (GNU GPL).
- * Please read the included file COPYING for more information.
- * This software comes with no warranty of any kind, use at your own risk!
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifndef OPTIONS_H
@@ -29,6 +38,7 @@ struct _ConfOptions
 	gboolean update_on_time_change;
 
 	guint duplicates_similarity_threshold;
+	gboolean rot_invariant_sim;
 
 	gint open_recent_list_maxsize;
 	gint dnd_icon_size;
@@ -66,7 +76,7 @@ struct _ConfOptions
 		gboolean zoom_2pass;
 		gboolean zoom_to_fit_allow_expand;
 		guint zoom_quality;
-		gint zoom_increment;	/* 10 is 1.0, 5 is 0.05, 20 is 2.0, etc. */
+		gint zoom_increment;	/* 100 is 1.0, 5 is 0.05, 200 is 2.0, etc. */
 		gboolean use_clutter_renderer;
 
 		gboolean use_custom_border_color_in_fullscreen;
@@ -89,7 +99,9 @@ struct _ConfOptions
 	/* file filtering */
 	struct {
 		gboolean show_hidden_files;
+		gboolean show_parent_directory;
 		gboolean show_dot_directory;
+		gboolean disable_file_extension_checks;
 		gboolean disable;
 	} file_filter;
 
@@ -135,6 +147,15 @@ struct _ConfOptions
 		gchar *template_string;
 		gint x;
 		gint y;
+		guint16 text_red;
+		guint16 text_green;
+		guint16 text_blue;
+		guint16 text_alpha;
+		guint16 background_red;
+		guint16 background_green;
+		guint16 background_blue;
+		guint16 background_alpha;
+		gchar *font;
 	} image_overlay;
 
 	/* properties dialog */
