@@ -1,16 +1,24 @@
 /*
- * Geeqie
- * (C) 2006 John Ellis
- * Copyright (C) 2008 - 2012 The Geeqie Team
+ * Copyright (C) 2006 John Ellis
+ * Copyright (C) 2008 - 2016 The Geeqie Team
  *
  * Author: John Ellis
  *
- * This software is released under the GNU General Public License (GNU GPL).
- * Please read the included file COPYING for more information.
- * This software comes with no warranty of any kind, use at your own risk!
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-
 #include "main.h"
 #include "preferences.h"
 
@@ -44,6 +52,7 @@
 #define EDITOR_NAME_MAX_LENGTH 32
 #define EDITOR_COMMAND_MAX_LENGTH 1024
 
+static void image_overlay_set_text_colours();
 
 typedef struct _ThumbSize ThumbSize;
 struct _ThumbSize
@@ -137,7 +146,7 @@ static void scroll_reset_cb(GtkWidget *widget, gpointer data)
 
 static void zoom_increment_cb(GtkWidget *spin, gpointer data)
 {
-	c_options->image.zoom_increment = (gint)(gtk_spin_button_get_value(GTK_SPIN_BUTTON(spin)) * 10.0 + 0.01);
+	c_options->image.zoom_increment = (gint)(gtk_spin_button_get_value(GTK_SPIN_BUTTON(spin)) * 100.0 + 0.01);
 }
 
 static void slideshow_delay_cb(GtkWidget *spin, gpointer data)
@@ -197,8 +206,10 @@ static void config_window_apply(void)
 	config_entry_to_option(safe_delete_path_entry, &options->file_ops.safe_delete_path, remove_trailing_slash);
 
 	if (options->file_filter.show_hidden_files != c_options->file_filter.show_hidden_files) refresh = TRUE;
+	if (options->file_filter.show_parent_directory != c_options->file_filter.show_parent_directory) refresh = TRUE;
 	if (options->file_filter.show_dot_directory != c_options->file_filter.show_dot_directory) refresh = TRUE;
 	if (options->file_sort.case_sensitive != c_options->file_sort.case_sensitive) refresh = TRUE;
+	if (options->file_filter.disable_file_extension_checks != c_options->file_filter.disable_file_extension_checks) refresh = TRUE;
 	if (options->file_filter.disable != c_options->file_filter.disable) refresh = TRUE;
 
 	options->file_ops.confirm_delete = c_options->file_ops.confirm_delete;
@@ -234,7 +245,9 @@ static void config_window_apply(void)
 	options->thumbnails.spec_standard = c_options->thumbnails.spec_standard;
 	options->metadata.enable_metadata_dirs = c_options->metadata.enable_metadata_dirs;
 	options->file_filter.show_hidden_files = c_options->file_filter.show_hidden_files;
+	options->file_filter.show_parent_directory = c_options->file_filter.show_parent_directory;
 	options->file_filter.show_dot_directory = c_options->file_filter.show_dot_directory;
+	options->file_filter.disable_file_extension_checks = c_options->file_filter.disable_file_extension_checks;
 
 	options->file_sort.case_sensitive = c_options->file_sort.case_sensitive;
 	options->file_filter.disable = c_options->file_filter.disable;
@@ -280,12 +293,23 @@ static void config_window_apply(void)
 	if (c_options->image_overlay.template_string)
 		set_image_overlay_template_string(&options->image_overlay.template_string,
 						  c_options->image_overlay.template_string);
-
+	if (c_options->image_overlay.font)
+		set_image_overlay_font_string(&options->image_overlay.font,
+						  c_options->image_overlay.font);
+	options->image_overlay.text_red = c_options->image_overlay.text_red;
+	options->image_overlay.text_green = c_options->image_overlay.text_green;
+	options->image_overlay.text_blue = c_options->image_overlay.text_blue;
+	options->image_overlay.text_alpha = c_options->image_overlay.text_alpha;
+	options->image_overlay.background_red = c_options->image_overlay.background_red;
+	options->image_overlay.background_green = c_options->image_overlay.background_green;
+	options->image_overlay.background_blue = c_options->image_overlay.background_blue;
+	options->image_overlay.background_alpha = c_options->image_overlay.background_alpha;
 	options->update_on_time_change = c_options->update_on_time_change;
 	options->image.exif_rotate_enable = c_options->image.exif_rotate_enable;
 	options->image.exif_proof_rotate_enable = c_options->image.exif_proof_rotate_enable;
 
 	options->duplicates_similarity_threshold = c_options->duplicates_similarity_threshold;
+	options->rot_invariant_sim = c_options->rot_invariant_sim;
 
 	options->tree_descend_subdirs = c_options->tree_descend_subdirs;
 
@@ -528,24 +552,42 @@ static void stereo_mode_menu_cb(GtkWidget *combo, gpointer data)
 			*option = PR_STEREO_ANAGLYPH_RC;
 			break;
 		case 2:
-			*option = PR_STEREO_ANAGLYPH_GRAY;
+			*option = PR_STEREO_ANAGLYPH_GM;
 			break;
 		case 3:
-			*option = PR_STEREO_ANAGLYPH_DB;
+			*option = PR_STEREO_ANAGLYPH_YB;
 			break;
 		case 4:
-			*option = PR_STEREO_HORIZ;
+			*option = PR_STEREO_ANAGLYPH_GRAY_RC;
 			break;
 		case 5:
-			*option = PR_STEREO_HORIZ | PR_STEREO_HALF;
+			*option = PR_STEREO_ANAGLYPH_GRAY_GM;
 			break;
 		case 6:
-			*option = PR_STEREO_VERT;
+			*option = PR_STEREO_ANAGLYPH_GRAY_YB;
 			break;
 		case 7:
-			*option = PR_STEREO_VERT | PR_STEREO_HALF;
+			*option = PR_STEREO_ANAGLYPH_DB_RC;
 			break;
 		case 8:
+			*option = PR_STEREO_ANAGLYPH_DB_GM;
+			break;
+		case 9:
+			*option = PR_STEREO_ANAGLYPH_DB_YB;
+			break;
+		case 10:
+			*option = PR_STEREO_HORIZ;
+			break;
+		case 11:
+			*option = PR_STEREO_HORIZ | PR_STEREO_HALF;
+			break;
+		case 12:
+			*option = PR_STEREO_VERT;
+			break;
+		case 13:
+			*option = PR_STEREO_VERT | PR_STEREO_HALF;
+			break;
+		case 14:
 			*option = PR_STEREO_FIXED;
 			break;
 		}
@@ -567,31 +609,43 @@ static void add_stereo_mode_menu(GtkWidget *table, gint column, gint row, const
 
 	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), _("Anaglyph Red-Cyan"));
 	if (option & PR_STEREO_ANAGLYPH_RC) current = 1;
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), _("Anaglyph Green-Magenta"));
+	if (option & PR_STEREO_ANAGLYPH_GM) current = 2;
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), _("Anaglyph Yellow-Blue"));
+	if (option & PR_STEREO_ANAGLYPH_YB) current = 3;
 	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), _("Anaglyph Gray Red-Cyan"));
-	if (option & PR_STEREO_ANAGLYPH_GRAY) current = 2;
-	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), _("Anaglyph Dubois"));
-	if (option & PR_STEREO_ANAGLYPH_DB) current = 3;
+	if (option & PR_STEREO_ANAGLYPH_GRAY_RC) current = 4;
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), _("Anaglyph Gray Green-Magenta"));
+	if (option & PR_STEREO_ANAGLYPH_GRAY_GM) current = 5;
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), _("Anaglyph Gray Yellow-Blue"));
+	if (option & PR_STEREO_ANAGLYPH_GRAY_YB) current = 6;
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), _("Anaglyph Dubois Red-Cyan"));
+	if (option & PR_STEREO_ANAGLYPH_DB_RC) current = 7;
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), _("Anaglyph Dubois Green-Magenta"));
+	if (option & PR_STEREO_ANAGLYPH_DB_GM) current = 8;
+	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), _("Anaglyph Dubois Yellow-Blue"));
+	if (option & PR_STEREO_ANAGLYPH_DB_YB) current = 9;
 
 	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), _("Side by Side"));
 	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), _("Side by Side Half size"));
 	if (option & PR_STEREO_HORIZ)
 		{
-		current = 4;
-		if (option & PR_STEREO_HALF) current = 5;
+		current = 10;
+		if (option & PR_STEREO_HALF) current = 11;
 		}
 
 	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), _("Top - Bottom"));
 	gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), _("Top - Bottom Half size"));
 	if (option & PR_STEREO_VERT)
 		{
-		current = 6;
-		if (option & PR_STEREO_HALF) current = 7;
+		current = 12;
+		if (option & PR_STEREO_HALF) current = 13;
 		}
 
 	if (add_fixed)
 		{
 		gtk_combo_box_text_append_text(GTK_COMBO_BOX_TEXT(combo), _("Fixed position"));
-		if (option & PR_STEREO_FIXED) current = 8;
+		if (option & PR_STEREO_FIXED) current = 14;
 		}
 
 	gtk_combo_box_set_active(GTK_COMBO_BOX(combo), current);
@@ -980,6 +1034,133 @@ static void image_overlay_help_cb(GtkWidget *widget, gpointer data)
 	help_window_show("overlay");
 }
 
+static void image_overlay_set_font_cb(GtkWidget *widget, gpointer data)
+{
+#if GTK_CHECK_VERSION(3,4,0)
+	GtkWidget *dialog;
+	char *font;
+	PangoFontDescription *font_desc;
+
+	dialog = gtk_font_chooser_dialog_new("Image Overlay Font", GTK_WINDOW(gtk_widget_get_toplevel(widget)));
+	gtk_font_chooser_set_font(GTK_FONT_CHOOSER(dialog), options->image_overlay.font);
+
+	if (gtk_dialog_run(GTK_DIALOG(dialog)) != GTK_RESPONSE_CANCEL)
+		{
+		font_desc = gtk_font_chooser_get_font_desc(GTK_FONT_CHOOSER(dialog));
+		font = pango_font_description_to_string(font_desc);
+		g_free(c_options->image_overlay.font);
+		c_options->image_overlay.font = g_strdup(font);
+		g_free(font);
+		}
+
+	gtk_widget_destroy(dialog);
+#else
+	const char *font;
+
+	font = gtk_font_button_get_font_name(GTK_FONT_BUTTON(widget));
+	c_options->image_overlay.font = g_strdup(font);
+#endif
+}
+
+static void image_overlay_set_text_colour_cb(GtkWidget *widget, gpointer data)
+{
+	GtkWidget *dialog;
+#if GTK_CHECK_VERSION(3,4,0)
+	GdkRGBA colour;
+
+	dialog = gtk_color_chooser_dialog_new("Image Overlay Text Colour", GTK_WINDOW(gtk_widget_get_toplevel(widget)));
+	colour.red = options->image_overlay.text_red;
+	colour.green = options->image_overlay.text_green;
+	colour.blue = options->image_overlay.text_blue;
+	colour.alpha = options->image_overlay.text_alpha;
+	gtk_color_chooser_set_rgba(GTK_COLOR_CHOOSER(dialog), &colour);
+	gtk_color_chooser_set_use_alpha(GTK_COLOR_CHOOSER(dialog), TRUE);
+
+	if (gtk_dialog_run(GTK_DIALOG(dialog)) != GTK_RESPONSE_CANCEL)
+		{
+		gtk_color_chooser_get_rgba(GTK_COLOR_CHOOSER(dialog), &colour);
+		c_options->image_overlay.text_red = colour.red*255;
+		c_options->image_overlay.text_green = colour.green*255;
+		c_options->image_overlay.text_blue = colour.blue*255;
+		c_options->image_overlay.text_alpha = colour.alpha*255;
+		}
+	gtk_widget_destroy(dialog);
+#else
+	GdkColor colour;
+	GtkColorSelection *colorsel;
+
+	dialog = gtk_color_selection_dialog_new("Image Overlay Text Colour");
+	gtk_window_set_keep_above(GTK_WINDOW(dialog),TRUE);
+	colour.red = options->image_overlay.text_red*257;
+	colour.green = options->image_overlay.text_green*257;
+	colour.blue = options->image_overlay.text_blue*257;
+	colorsel = GTK_COLOR_SELECTION(gtk_color_selection_dialog_get_color_selection(GTK_COLOR_SELECTION_DIALOG(dialog)));
+	gtk_color_selection_set_has_opacity_control(colorsel, TRUE);
+	gtk_color_selection_set_current_color(colorsel, &colour);
+	gtk_color_selection_set_current_alpha(colorsel, options->image_overlay.text_alpha*257);
+
+	if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_OK)
+		{
+		gtk_color_selection_get_current_color(colorsel, &colour);
+		c_options->image_overlay.text_red = colour.red/257;
+		c_options->image_overlay.text_green = colour.green/257;
+		c_options->image_overlay.text_blue = colour.blue/257;
+		c_options->image_overlay.text_alpha = gtk_color_selection_get_current_alpha(colorsel)/257;
+		}
+	gtk_widget_destroy (dialog);
+#endif
+}
+
+
+static void image_overlay_set_background_colour_cb(GtkWidget *widget, gpointer data)
+{
+	GtkWidget *dialog;
+#if GTK_CHECK_VERSION(3,4,0)
+	GdkRGBA colour;
+
+	dialog = gtk_color_chooser_dialog_new("Image Overlay Background Colour", GTK_WINDOW(gtk_widget_get_toplevel(widget)));
+	colour.red = options->image_overlay.background_red;
+	colour.green = options->image_overlay.background_green;
+	colour.blue = options->image_overlay.background_blue;
+	colour.alpha = options->image_overlay.background_alpha;
+	gtk_color_chooser_set_rgba(GTK_COLOR_CHOOSER(dialog), &colour);
+	gtk_color_chooser_set_use_alpha(GTK_COLOR_CHOOSER(dialog), TRUE);
+
+	if (gtk_dialog_run(GTK_DIALOG(dialog)) != GTK_RESPONSE_CANCEL)
+		{
+		gtk_color_chooser_get_rgba(GTK_COLOR_CHOOSER(dialog), &colour);
+		c_options->image_overlay.background_red = colour.red*255;
+		c_options->image_overlay.background_green = colour.green*255;
+		c_options->image_overlay.background_blue = colour.blue*255;
+		c_options->image_overlay.background_alpha = colour.alpha*255;
+		}
+	gtk_widget_destroy(dialog);
+#else
+	GdkColor colour;
+	GtkColorSelection *colorsel;
+
+	dialog = gtk_color_selection_dialog_new("Image Overlay Background Colour");
+	gtk_window_set_keep_above(GTK_WINDOW(dialog),TRUE);
+	colour.red = options->image_overlay.background_red*257;
+	colour.green = options->image_overlay.background_green*257;
+	colour.blue = options->image_overlay.background_blue*257;
+	colorsel = GTK_COLOR_SELECTION(gtk_color_selection_dialog_get_color_selection(GTK_COLOR_SELECTION_DIALOG(dialog)));
+	gtk_color_selection_set_has_opacity_control(colorsel, TRUE);
+	gtk_color_selection_set_current_color(colorsel, &colour);
+	gtk_color_selection_set_current_alpha(colorsel, options->image_overlay.background_alpha*257);
+
+	if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_OK)
+		{
+		gtk_color_selection_get_current_color(colorsel, &colour);
+		c_options->image_overlay.background_red = colour.red/257;
+		c_options->image_overlay.background_green = colour.green/257;
+		c_options->image_overlay.background_blue = colour.blue/257;
+		c_options->image_overlay.background_alpha = gtk_color_selection_get_current_alpha(colorsel)/257;
+		}
+	gtk_widget_destroy(dialog);
+#endif
+}
+
 static void accel_store_populate(void)
 {
 	LayoutWindow *lw;
@@ -1285,7 +1466,7 @@ static void config_tab_image(GtkWidget *notebook)
 
 	c_options->image.zoom_increment = options->image.zoom_increment;
 	spin = pref_spin_new(group, _("Zoom increment:"), NULL,
-			     0.1, 4.0, 0.1, 1, (gdouble)options->image.zoom_increment / 10.0,
+			     0.01, 4.0, 0.01, 2, (gdouble)options->image.zoom_increment / 100.0,
 			     G_CALLBACK(zoom_increment_cb), NULL);
 	gtk_spin_button_set_update_policy(GTK_SPIN_BUTTON(spin), GTK_UPDATE_ALWAYS);
 
@@ -1416,6 +1597,30 @@ static void config_tab_windows(GtkWidget *notebook)
 
 	hbox = pref_box_new(group, FALSE, GTK_ORIENTATION_HORIZONTAL, PREF_PAD_BUTTON_GAP);
 
+#if GTK_CHECK_VERSION(3,4,0)
+	button = pref_button_new(NULL, GTK_STOCK_SELECT_FONT, _("Font"), FALSE,
+				 G_CALLBACK(image_overlay_set_font_cb), notebook);
+#else
+	button = gtk_font_button_new();
+	gtk_font_button_set_title(GTK_FONT_BUTTON(button), "Image Overlay Font");
+	gtk_font_button_set_font_name(GTK_FONT_BUTTON(button), options->image_overlay.font);
+	g_signal_connect(G_OBJECT(button), "font-set",
+				 G_CALLBACK(image_overlay_set_font_cb),NULL);
+#endif
+	gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 0);
+	gtk_widget_show(button);
+
+	button = pref_button_new(NULL, GTK_STOCK_COLOR_PICKER, _("Text"), FALSE,
+				 G_CALLBACK(image_overlay_set_text_colour_cb), NULL);
+	gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 0);
+	gtk_widget_show(button);
+
+	button = pref_button_new(NULL, GTK_STOCK_COLOR_PICKER, _("Background"), FALSE,
+				 G_CALLBACK(image_overlay_set_background_colour_cb), NULL);
+	gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 0);
+	gtk_widget_show(button);
+	image_overlay_set_text_colours();
+
 	button = pref_button_new(NULL, NULL, _("Defaults"), FALSE,
 				 G_CALLBACK(image_overlay_default_template_cb), image_overlay_template_view);
 	gtk_box_pack_end(GTK_BOX(hbox), button, FALSE, FALSE, 0);
@@ -1472,8 +1677,12 @@ static void config_tab_files(GtkWidget *notebook)
 
 	pref_checkbox_new_int(group, _("Show hidden files or folders"),
 			      options->file_filter.show_hidden_files, &c_options->file_filter.show_hidden_files);
+	pref_checkbox_new_int(group, _("Show parent folder (..)"),
+			      options->file_filter.show_parent_directory, &c_options->file_filter.show_parent_directory);
 	pref_checkbox_new_int(group, _("Case sensitive sort"),
 			      options->file_sort.case_sensitive, &c_options->file_sort.case_sensitive);
+	pref_checkbox_new_int(group, _("Disable file extension checks"),
+			      options->file_filter.disable_file_extension_checks, &c_options->file_filter.disable_file_extension_checks);
 
 	ct_button = pref_checkbox_new_int(group, _("Disable File Filtering"),
 					  options->file_filter.disable, &c_options->file_filter.disable);
@@ -1850,11 +2059,12 @@ static void config_tab_behavior(GtkWidget *notebook)
 	pref_checkbox_new_int(group, _("Mouse wheel scrolls image"),
 			      options->mousewheel_scrolls, &c_options->mousewheel_scrolls);
 
-	group = pref_group_new(vbox, FALSE, _("Miscellaneous"), GTK_ORIENTATION_VERTICAL);
+	group = pref_group_new(vbox, FALSE, _("Similarities"), GTK_ORIENTATION_VERTICAL);
 
 	pref_spin_new_int(group, _("Custom similarity threshold:"), NULL,
 			  0, 100, 1, options->duplicates_similarity_threshold, (int *)&c_options->duplicates_similarity_threshold);
-
+	pref_checkbox_new_int(group, _("Rotation invariant duplicate check"),
+			      options->rot_invariant_sim, &c_options->rot_invariant_sim);
 
 #ifdef DEBUG
 	group = pref_group_new(vbox, FALSE, _("Debugging"), GTK_ORIENTATION_VERTICAL);
@@ -2207,7 +2417,7 @@ void show_about_window(void)
 	buf = g_strdup_printf(_("%s %s\n\nCopyright (c) 2006 John Ellis\nCopyright (c) %s The Geeqie Team\nwebsite: %s\nemail: %s\n\nReleased under the GNU General Public License"),
 			      GQ_APPNAME,
 			      VERSION,
-			      "2008 - 2012",
+			      "2008 - 2016",
 			      GQ_WEBSITE,
 			      GQ_EMAIL_ADDRESS);
 	label = gtk_label_new(buf);
@@ -2238,4 +2448,16 @@ void show_about_window(void)
 
 	gtk_widget_show(about);
 }
+
+static void image_overlay_set_text_colours()
+{
+	c_options->image_overlay.text_red = options->image_overlay.text_red;
+	c_options->image_overlay.text_green = options->image_overlay.text_green;
+	c_options->image_overlay.text_blue = options->image_overlay.text_blue;
+	c_options->image_overlay.text_alpha = options->image_overlay.text_alpha;
+	c_options->image_overlay.background_red = options->image_overlay.background_red;
+	c_options->image_overlay.background_green = options->image_overlay.background_green;
+	c_options->image_overlay.background_blue = options->image_overlay.background_blue;
+	c_options->image_overlay.background_alpha = options->image_overlay.background_alpha;
+}
 /* vim: set shiftwidth=8 softtabstop=0 cindent cinoptions={1s: */
