@@ -1,13 +1,22 @@
 /*
- * Geeqie
- * (C) 2006 John Ellis
- * Copyright (C) 2008 - 2012 The Geeqie Team
+ * Copyright (C) 2006 John Ellis
+ * Copyright (C) 2008 - 2016 The Geeqie Team
  *
  * Author: John Ellis
  *
- * This software is released under the GNU General Public License (GNU GPL).
- * Please read the included file COPYING for more information.
- * This software comes with no warranty of any kind, use at your own risk!
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #include <glib/gstdio.h>
@@ -281,6 +290,7 @@ static void write_global_attributes(GString *outstr, gint indent)
 	WRITE_NL(); WRITE_BOOL(*options, progressive_key_scrolling);
 
 	WRITE_NL(); WRITE_UINT(*options, duplicates_similarity_threshold);
+	WRITE_NL(); WRITE_BOOL(*options, rot_invariant_sim);
 	WRITE_SEPARATOR();
 
 	WRITE_NL(); WRITE_BOOL(*options, mousewheel_scrolls);
@@ -353,6 +363,15 @@ static void write_global_attributes(GString *outstr, gint indent)
 
 	WRITE_NL(); WRITE_INT(*options, image_overlay.x);
 	WRITE_NL(); WRITE_INT(*options, image_overlay.y);
+	WRITE_NL(); WRITE_INT(*options, image_overlay.text_red);
+	WRITE_NL(); WRITE_INT(*options, image_overlay.text_green);
+	WRITE_NL(); WRITE_INT(*options, image_overlay.text_blue);
+	WRITE_NL(); WRITE_INT(*options, image_overlay.text_alpha);
+	WRITE_NL(); WRITE_INT(*options, image_overlay.background_red);
+	WRITE_NL(); WRITE_INT(*options, image_overlay.background_green);
+	WRITE_NL(); WRITE_INT(*options, image_overlay.background_blue);
+	WRITE_NL(); WRITE_INT(*options, image_overlay.background_alpha);
+	WRITE_NL(); WRITE_CHAR(*options, image_overlay.font);
 
 	/* Slideshow Options */
 	WRITE_NL(); WRITE_INT_UNIT(*options, slideshow.delay, SLIDESHOW_SUBSECOND_PRECISION);
@@ -364,7 +383,9 @@ static void write_global_attributes(GString *outstr, gint indent)
 
 	/* Filtering Options */
 	WRITE_NL(); WRITE_BOOL(*options, file_filter.show_hidden_files);
+	WRITE_NL(); WRITE_BOOL(*options, file_filter.show_parent_directory);
 	WRITE_NL(); WRITE_BOOL(*options, file_filter.show_dot_directory);
+	WRITE_NL(); WRITE_BOOL(*options, file_filter.disable_file_extension_checks);
 	WRITE_NL(); WRITE_BOOL(*options, file_filter.disable);
 	WRITE_SEPARATOR();
 
@@ -541,6 +562,7 @@ static gboolean load_global_params(const gchar **attribute_names, const gchar **
 		if (READ_BOOL(*options, update_on_time_change)) continue;
 
 		if (READ_UINT_CLAMP(*options, duplicates_similarity_threshold, 0, 100)) continue;
+		if (READ_BOOL(*options, rot_invariant_sim)) continue;
 
 		if (READ_BOOL(*options, progressive_key_scrolling)) continue;
 
@@ -611,6 +633,15 @@ static gboolean load_global_params(const gchar **attribute_names, const gchar **
 		if (READ_CHAR(*options, image_overlay.template_string)) continue;
 		if (READ_INT(*options, image_overlay.x)) continue;
 		if (READ_INT(*options, image_overlay.y)) continue;
+		if (READ_INT(*options, image_overlay.text_red)) continue;
+		if (READ_INT(*options, image_overlay.text_green)) continue;
+		if (READ_INT(*options, image_overlay.text_blue)) continue;
+		if (READ_INT(*options, image_overlay.text_alpha)) continue;
+		if (READ_INT(*options, image_overlay.background_red)) continue;
+		if (READ_INT(*options, image_overlay.background_green)) continue;
+		if (READ_INT(*options, image_overlay.background_blue)) continue;
+		if (READ_INT(*options, image_overlay.background_alpha)) continue;
+		if (READ_CHAR(*options, image_overlay.font)) continue;
 
 		/* Slideshow options */
 		if (READ_INT_UNIT(*options, slideshow.delay, SLIDESHOW_SUBSECOND_PRECISION)) continue;
@@ -622,7 +653,9 @@ static gboolean load_global_params(const gchar **attribute_names, const gchar **
 
 		/* Filtering options */
 		if (READ_BOOL(*options, file_filter.show_hidden_files)) continue;
+		if (READ_BOOL(*options, file_filter.show_parent_directory)) continue;
 		if (READ_BOOL(*options, file_filter.show_dot_directory)) continue;
+		if (READ_BOOL(*options, file_filter.disable_file_extension_checks)) continue;
 		if (READ_BOOL(*options, file_filter.disable)) continue;
 		if (READ_CHAR(*options, sidecar.ext)) continue;
 
@@ -952,44 +985,13 @@ static void options_parse_bar(GQParserData *parser_data, GMarkupParseContext *co
 		}
 }
 
-static void options_parse_toolbar(GQParserData *parser_data, GMarkupParseContext *context, const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **error)
+/* Just a dummy function to parse out old leftovers
+ *
+ * This function can be cleaned somedays.
+ */
+static void options_parse_toolbar_and_statusbar(GQParserData *parser_data, GMarkupParseContext *context, const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **error)
 {
-	LayoutWindow *lw = data;
-	if (g_ascii_strcasecmp(element_name, "toolitem") == 0)
-		{
-		layout_toolbar_add_from_config(lw, TOOLBAR_MAIN, attribute_names, attribute_values);
-		options_parse_func_push(parser_data, options_parse_leaf, NULL, NULL);
-		}
-	else if (g_ascii_strcasecmp(element_name, "clear") == 0)
-		{
-		layout_toolbar_clear(lw, TOOLBAR_MAIN);
-		options_parse_func_push(parser_data, options_parse_leaf, NULL, NULL);
-		}
-	else
-		{
-		log_printf("unexpected in <toolbar>: <%s>\n", element_name);
-		options_parse_func_push(parser_data, options_parse_leaf, NULL, NULL);
-		}
-}
-
-static void options_parse_statusbar(GQParserData *parser_data, GMarkupParseContext *context, const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **error)
-{
-	LayoutWindow *lw = data;
-	if (g_ascii_strcasecmp(element_name, "toolitem") == 0)
-		{
-		layout_toolbar_add_from_config(lw, TOOLBAR_STATUS, attribute_names, attribute_values);
-		options_parse_func_push(parser_data, options_parse_leaf, NULL, NULL);
-		}
-	else if (g_ascii_strcasecmp(element_name, "clear") == 0)
-		{
-		layout_toolbar_clear(lw, TOOLBAR_STATUS);
-		options_parse_func_push(parser_data, options_parse_leaf, NULL, NULL);
-		}
-	else
-		{
-		log_printf("unexpected in <statusbar>: <%s>\n", element_name);
-		options_parse_func_push(parser_data, options_parse_leaf, NULL, NULL);
-		}
+	options_parse_func_push(parser_data, options_parse_leaf, NULL, NULL);
 }
 
 static void options_parse_layout(GQParserData *parser_data, GMarkupParseContext *context, const gchar *element_name, const gchar **attribute_names, const gchar **attribute_values, gpointer data, GError **error)
@@ -1017,11 +1019,11 @@ static void options_parse_layout(GQParserData *parser_data, GMarkupParseContext
 		}
 	else if (g_ascii_strcasecmp(element_name, "toolbar") == 0)
 		{
-		options_parse_func_push(parser_data, options_parse_toolbar, NULL, lw);
+		options_parse_func_push(parser_data, options_parse_toolbar_and_statusbar, NULL, NULL);
 		}
 	else if (g_ascii_strcasecmp(element_name, "statusbar") == 0)
 		{
-		options_parse_func_push(parser_data, options_parse_statusbar, NULL, lw);
+		options_parse_func_push(parser_data, options_parse_toolbar_and_statusbar, NULL, NULL);
 		}
 	else
 		{
