@@ -1,16 +1,24 @@
 /*
- * Geeqie
- * (C) 2006 John Ellis
- * Copyright (C) 2008 - 2012 The Geeqie Team
+ * Copyright (C) 2006 John Ellis
+ * Copyright (C) 2008 - 2016 The Geeqie Team
  *
  * Author: John Ellis
  *
- * This software is released under the GNU General Public License (GNU GPL).
- * Please read the included file COPYING for more information.
- * This software comes with no warranty of any kind, use at your own risk!
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-
 #ifndef TYPEDEFS_H
 #define TYPEDEFS_H
 
@@ -49,6 +57,7 @@ typedef enum {
 	SORT_NAME,
 	SORT_SIZE,
 	SORT_TIME,
+	SORT_CTIME,
 	SORT_PATH,
 	SORT_NUMBER,
 	SORT_EXIFTIME
@@ -160,10 +169,11 @@ typedef enum {
 	CHANGE_WARN_CHANGED_EXT        = 1 << 3,
 	CHANGE_WARN_UNSAVED_META       = 1 << 4,
 	CHANGE_WARN_NO_WRITE_PERM_DEST_DIR  = 1 << 5,
-	CHANGE_ERROR_MASK              = (~0) << 8, /* the values below are fatal errors */
+	CHANGE_ERROR_MASK              = (~0U) << 8, /* the values below are fatal errors */
 	CHANGE_NO_READ_PERM            = 1 << 8,
 	CHANGE_NO_WRITE_PERM_DIR       = 1 << 9,
 	CHANGE_NO_DEST_DIR             = 1 << 10,
+	CHANGE_DUPLICATE_DEST          = 1 << 11,
 	CHANGE_NO_WRITE_PERM_DEST      = 1 << 12,
 	CHANGE_DEST_EXISTS             = 1 << 13,
 	CHANGE_NO_SRC                  = 1 << 14,
@@ -188,28 +198,42 @@ typedef enum {
 } ToolbarType;
 
 typedef enum {
-	PR_STEREO_NONE           = 0,	  /* do nothing */
-	PR_STEREO_DUAL           = 1 << 0, /* independent stereo buffers, for example nvidia opengl */
-	PR_STEREO_FIXED          = 1 << 1, /* custom position */
-	PR_STEREO_HORIZ          = 1 << 2, /* side by side */
-	PR_STEREO_VERT           = 1 << 3, /* above below */
-	PR_STEREO_RIGHT          = 1 << 4, /* render right buffer */
-	PR_STEREO_ANAGLYPH_RC    = 1 << 5, /* anaglyph red-cyan */
-	PR_STEREO_ANAGLYPH_GRAY  = 1 << 6, /* anaglyph gray red-cyan*/
-	PR_STEREO_ANAGLYPH_DB    = 1 << 7, /* anaglyph dubois*/
-	PR_STEREO_ANAGLYPH       = PR_STEREO_ANAGLYPH_RC | PR_STEREO_ANAGLYPH_GRAY | PR_STEREO_ANAGLYPH_DB, /* anaglyph mask */
+	PR_STEREO_NONE             = 0,	  /* do nothing */
+	PR_STEREO_DUAL             = 1 << 0, /* independent stereo buffers, for example nvidia opengl */
+	PR_STEREO_FIXED            = 1 << 1,  /* custom position */
+	PR_STEREO_HORIZ            = 1 << 2,  /* side by side */
+	PR_STEREO_VERT             = 1 << 3,  /* above below */
+	PR_STEREO_RIGHT            = 1 << 4,  /* render right buffer */
+	PR_STEREO_ANAGLYPH_RC      = 1 << 5,  /* anaglyph red-cyan */
+	PR_STEREO_ANAGLYPH_GM      = 1 << 6,  /* anaglyph green-magenta */
+	PR_STEREO_ANAGLYPH_YB      = 1 << 7,  /* anaglyph yellow-blue */
+	PR_STEREO_ANAGLYPH_GRAY_RC = 1 << 8,  /* anaglyph gray red-cyan*/
+	PR_STEREO_ANAGLYPH_GRAY_GM = 1 << 9,  /* anaglyph gray green-magenta */
+	PR_STEREO_ANAGLYPH_GRAY_YB = 1 << 10, /* anaglyph gray yellow-blue */
+	PR_STEREO_ANAGLYPH_DB_RC   = 1 << 11, /* anaglyph dubois red-cyan */
+	PR_STEREO_ANAGLYPH_DB_GM   = 1 << 12, /* anaglyph dubois green-magenta */
+	PR_STEREO_ANAGLYPH_DB_YB   = 1 << 13, /* anaglyph dubois yellow-blue */
+	PR_STEREO_ANAGLYPH         = PR_STEREO_ANAGLYPH_RC |
+	                             PR_STEREO_ANAGLYPH_GM |
+	                             PR_STEREO_ANAGLYPH_YB |
+	                             PR_STEREO_ANAGLYPH_GRAY_RC |
+	                             PR_STEREO_ANAGLYPH_GRAY_GM |
+	                             PR_STEREO_ANAGLYPH_GRAY_YB |
+	                             PR_STEREO_ANAGLYPH_DB_RC |
+	                             PR_STEREO_ANAGLYPH_DB_GM |
+	                             PR_STEREO_ANAGLYPH_DB_YB, /* anaglyph mask */
 
-	PR_STEREO_MIRROR_LEFT    = 1 << 8, /* mirror */
-	PR_STEREO_FLIP_LEFT      = 1 << 9, /* flip */
+	PR_STEREO_MIRROR_LEFT      = 1 << 14, /* mirror */
+	PR_STEREO_FLIP_LEFT        = 1 << 15, /* flip */
 
-	PR_STEREO_MIRROR_RIGHT   = 1 << 10, /* mirror */
-	PR_STEREO_FLIP_RIGHT     = 1 << 11, /* flip */
+	PR_STEREO_MIRROR_RIGHT     = 1 << 16, /* mirror */
+	PR_STEREO_FLIP_RIGHT       = 1 << 17, /* flip */
 
-	PR_STEREO_MIRROR         = PR_STEREO_MIRROR_LEFT | PR_STEREO_MIRROR_RIGHT, /* mirror mask*/
-	PR_STEREO_FLIP           = PR_STEREO_FLIP_LEFT | PR_STEREO_FLIP_RIGHT, /* flip mask*/
-	PR_STEREO_SWAP           = 1 << 12,  /* swap left and right buffers */
-	PR_STEREO_TEMP_DISABLE   = 1 << 13,  /* temporarily disable stereo mode if source image is not stereo */
-	PR_STEREO_HALF           = 1 << 14
+	PR_STEREO_MIRROR           = PR_STEREO_MIRROR_LEFT | PR_STEREO_MIRROR_RIGHT, /* mirror mask*/
+	PR_STEREO_FLIP             = PR_STEREO_FLIP_LEFT | PR_STEREO_FLIP_RIGHT, /* flip mask*/
+	PR_STEREO_SWAP             = 1 << 18,  /* swap left and right buffers */
+	PR_STEREO_TEMP_DISABLE     = 1 << 19,  /* temporarily disable stereo mode if source image is not stereo */
+	PR_STEREO_HALF             = 1 << 20
 } PixbufRendererStereoMode;
 
 typedef enum {
@@ -497,6 +521,7 @@ struct _FileData {
 	gchar *collate_key_name_nocase;
 	gint64 size;
 	time_t date;
+	time_t cdate;
 	mode_t mode; /* this is needed at least for notification in view_dir because it is preserved after the file/directory is deleted */
 	gint sidecar_priority;
 
@@ -606,7 +631,6 @@ struct _LayoutWindow
 	GtkActionGroup *action_group_editors;
 	guint ui_editors_id;
 	GtkUIManager *ui_manager;
-	guint toolbar_merge_id[TOOLBAR_COUNT];
 	GList *toolbar_actions[TOOLBAR_COUNT];
 
 	GtkWidget *path_entry;
