@@ -1,13 +1,22 @@
 /*
- * (SLIK) SimpLIstic sKin functions
- * (C) 2004 John Ellis
- * Copyright (C) 2008 - 2012 The Geeqie Team
+ * Copyright (C) 2004 John Ellis
+ * Copyright (C) 2008 - 2016 The Geeqie Team
  *
  * Author: John Ellis
  *
- * This software is released under the GNU General Public License (GNU GPL).
- * Please read the included file COPYING for more information.
- * This software comes with no warranty of any kind, use at your own risk!
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -550,6 +559,10 @@ static void bookmark_populate(BookMarkData *bm)
 			history_list_add_to_key(bm->key, buf, 0);
 			g_free(buf);
 
+			buf = bookmark_string(".", g_strdup(history_list_find_last_path_by_key("path_list")), NULL);
+			history_list_add_to_key(bm->key, buf, 0);
+			g_free(buf);
+
 			path = g_build_filename(homedir(), "Desktop", NULL);
 			if (isname(path))
 				{
@@ -570,7 +583,14 @@ static void bookmark_populate(BookMarkData *bm)
 			path = work->data;
 			work = work->next;
 
-			buf = bookmark_string(name, path, NULL);
+			if (strcmp(name, ".") == 0)
+				{
+				buf = bookmark_string(name, g_strdup(history_list_find_last_path_by_key("path_list")), NULL);
+				}
+			else
+				{
+				buf = bookmark_string(name, path, NULL);
+				}
 			history_list_add_to_key(bm->key, buf, 0);
 			g_free(buf);
 			}
@@ -585,6 +605,16 @@ static void bookmark_populate(BookMarkData *bm)
 		b = bookmark_from_string(work->data);
 		if (b)
 			{
+			if (strcmp(b->name, ".") == 0)
+				{
+				gchar *buf;
+
+				b->path = g_strdup(history_list_find_last_path_by_key("path_list"));
+				buf = bookmark_string(".", b->path, b->icon);
+				history_list_item_change("bookmarks", b->key, buf);
+				b->key = g_strdup(buf);
+				g_free(buf);
+				}
 			GtkWidget *box;
 
 			b->button = gtk_button_new();
@@ -686,13 +716,19 @@ static void bookmark_dnd_get_data(GtkWidget *widget,
 {
 	BookMarkData *bm = data;
 	GList *list = NULL;
+	GList *errors = NULL;
 	GList *work;
 	gchar **uris;
 
 	if (!bm->editable) return;
 
 	uris = gtk_selection_data_get_uris(selection_data);
-	list = uri_filelist_from_uris(uris);
+	list = uri_filelist_from_uris(uris, &errors);
+	if(errors)
+		{
+		warning_dialog_dnd_uri_error(errors);
+		string_list_free(errors);
+		}
 	g_strfreev(uris);
 
 	work = list;
